===============================
airly
===============================

Python wrapper for getting air quality data from Airly sensors.

Samples
-------

Examples of how to use the library are under `samples` directory.
To run them, you need to create `samples\\.api_key` file, and fill it with
your Airly API Key.

Unit tests are also valuable source of information, so check them in case of any doubts.
